.. _artwork:

=======
Artwork
=======

High-quality logos are available in the `docs/source/images/ <https://github.com/sktime/sktime/tree/main/docs/source/images>`_ directory on GitHub.

The logos were designed by `Miguel Garcia Cabrera <https://www.flickr.com/photos/miguelgarciacabrera/>`_.
